@@ -8,12 +8,16 @@
 #include <time.h>
 #include <xmlrpc-c/util.h>
 #include <xmlrpc-c/config.h>
-  /* Defines XMLRPC_HAVE_WCHAR, XMLRPC_INT64 */
+  /* Defines XMLRPC_HAVE_WCHAR, XMLRPC_INT64, XMLRPC_HAVE_TIMEVAL */
 
 #if XMLRPC_HAVE_WCHAR
 #include <wchar.h>
 #endif
 
+#if XMLRPC_HAVE_TIMEVAL
+#include <sys/time.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -102,11 +106,11 @@ xmlrpc_abort_if_array_bad(xmlrpc_value * const arrayP);
     xmlrpc_abort_if_array_bad(val)
 
 /* Increment the reference count of an xmlrpc_value. */
-extern void xmlrpc_INCREF (xmlrpc_value* const value);
+extern void xmlrpc_INCREF(xmlrpc_value* const value);
 
 /* Decrement the reference count of an xmlrpc_value. If there
 ** are no more references, free it. */
-extern void xmlrpc_DECREF (xmlrpc_value* const value);
+extern void xmlrpc_DECREF(xmlrpc_value* const value);
 
 /* Get the type of an XML-RPC value. */
 extern xmlrpc_type xmlrpc_value_type (xmlrpc_value* const value);
@@ -316,12 +320,10 @@ int
 xmlrpc_array_size(xmlrpc_env *         const env, 
                   const xmlrpc_value * const array);
 
-/* Append an item to an XML-RPC array.
-** Sets XMLRPC_TYPE_ERROR if 'array' is not an array. */
-extern void
-xmlrpc_array_append_item (xmlrpc_env   * const envP,
-                          xmlrpc_value * const arrayP,
-                          xmlrpc_value * const valueP);
+void
+xmlrpc_array_append_item(xmlrpc_env   * const envP,
+                         xmlrpc_value * const arrayP,
+                         xmlrpc_value * const valueP);
 
 void
 xmlrpc_array_read_item(xmlrpc_env *         const envP,
@@ -342,11 +344,11 @@ xmlrpc_array_get_item(xmlrpc_env *         const envP,
                       int                  const index);
 
 /* Not implemented--we don't need it yet.
-extern 
-int xmlrpc_array_set_item (xmlrpc_env* env,
-xmlrpc_value* array,
-int index,
-                                  xmlrpc_value* value);
+int
+xmlrpc_array_set_item(xmlrpc_env *   const envP,
+                      xmlrpc_value * const arrayP,
+                      unsigned int   const index,
+                      xmlrpc_value * const valueP);
 */
 
 xmlrpc_value *
