@@ -1,5 +1,8 @@
 /* Copyright information is at the end of the file */
 
+#define _XOPEN_SOURCE 600   /* For strdup() */
+#define _BSD_SOURCE   /* For xmlrpc_strcaseeq() */
+
 #include <ctype.h>
 #include <assert.h>
 #include <stdlib.h>
@@ -179,8 +182,14 @@ getLineInBuffer(TConn * const connectionP,
             error = TRUE;
         else {
             lfPos = firstLfPos(connectionP, lineStart);
-            if (!lfPos)
-                error = !ConnRead(connectionP, timeLeft);
+            if (!lfPos) {
+                const char * readError;
+                ConnRead(connectionP, timeLeft, NULL, NULL, &readError);
+                if (readError) {
+                    error = TRUE;
+                    xmlrpc_strfree(readError);
+                }
+            }
         }
     }    
     *errorP = error;
@@ -431,14 +440,15 @@ readRequestHeader(TSession * const sessionP,
 
     skipToNonemptyLine(sessionP->conn, deadline, &error);
 
-    if (!error)
+    if (!error) {
         readHeader(sessionP->conn, deadline, &endOfHeaders, &line, &error);
 
-    /* End of headers is delimited by an empty line, and we skipped all
-       the empty lines above, so we could not have encountered EOH:
-    */
-    assert(!endOfHeaders);
-
+        /* End of headers is delimited by an empty line, and we skipped all
+           the empty lines above, so readHeader() could not have encountered
+           EOH:
+        */
+        assert(!endOfHeaders);
+    }
     if (error)
         *httpErrorCodeP = 408;  /* Request Timeout */
     else {
