@@ -6,6 +6,8 @@
   Copyright information is at the end of the file
 =============================================================================*/
 
+#define _XOPEN_SOURCE 600  /* Make sure strdup() is in <string.h> */
+
 #include <ctype.h>
 #include <assert.h>
 #include <stdlib.h>
@@ -16,11 +18,13 @@
 
 #include "xmlrpc_config.h"
 #include "bool.h"
+#include "int.h"
 #include "version.h"
 #include "mallocvar.h"
 #include "xmlrpc-c/string_int.h"
 #include "xmlrpc-c/abyss.h"
 
+#include "trace.h"
 #include "server.h"
 #include "session.h"
 #include "file.h"
@@ -202,6 +206,9 @@ ResponseWriteStart(TSession * const sessionP) {
 
     if (sessionP->status == 0) {
         /* Handler hasn't set status.  That's an error */
+        TraceMsg("Abyss client called ResponseWriteStart() on "
+                 "a session for which he has not set the request status "
+                 "('status' member of TSession).  Using status 500\n");
         sessionP->status = 500;
     }
 
@@ -650,7 +657,7 @@ Base64Encode(const char * const chars,
         '4','5','6','7','8','9','+','/'
     };
 
-    uint i;
+    unsigned int i;
     uint32_t length;
     char * p;
     const char * s;
