@@ -1,4 +1,8 @@
 /* Copyright information is at end of file */
+
+#define _XOPEN_SOURCE 600  /* Make sure strdup() is in <string.h> */
+#define _BSD_SOURCE  /* Make sure setgroups()is in <grp.h> */
+
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -468,7 +472,7 @@ void
 ServerSetKeepaliveTimeout(TServer *       const serverP,
                           xmlrpc_uint32_t const keepaliveTimeout) {
 
-    serverP->srvP->keepalivetimeout = keepaliveTimeout;
+    serverP->srvP->keepalivetimeout = MAX(keepaliveTimeout, 1);
 }
 
 
@@ -477,7 +481,7 @@ void
 ServerSetKeepaliveMaxConn(TServer *       const serverP,
                           xmlrpc_uint32_t const keepaliveMaxConn) {
 
-    serverP->srvP->keepalivemaxconn = keepaliveMaxConn;
+    serverP->srvP->keepalivemaxconn = MAX(keepaliveMaxConn, 1);
 }
 
 
@@ -613,14 +617,21 @@ serverFunc(void * const userHandle) {
     connectionDone = FALSE;
 
     while (!connectionDone) {
-        bool success;
+        bool timedOut, eof;
+        const char * readError;
         
-        /* Wait to read until timeout */
-        success = ConnRead(connectionP, srvP->keepalivetimeout);
+        ConnRead(connectionP, srvP->keepalivetimeout,
+                 &timedOut, &eof, &readError);
 
-        if (!success)
+        if (readError) {
+            TraceMsg("Failed to read from Abyss connection.  %s", readError);
+            xmlrpc_strfree(readError);
             connectionDone = TRUE;
-        else {
+        } else if (timedOut) {
+            connectionDone = TRUE;
+        } else if (eof) {
+            connectionDone = TRUE;
+        } else {
             bool const lastReqOnConn =
                 requestCount + 1 >= srvP->keepalivemaxconn;
 
@@ -971,6 +982,8 @@ acceptAndProcessNextConnection(
                    destroy *channelP.
                 */
             } else {
+                TraceMsg("Failed to create an Abyss connection "
+                         "out of new channel %lx.  %s", channelP, error);
                 xmlrpc_strfree(error);
                 ChannelDestroy(channelP);
                 free(channelInfoP);
