@@ -1,4 +1,5 @@
-#define _GNU_SOURCE
+#define _XOPEN_SOURCE 600  /* Make sure strdup() is in <string.h> */
+#define _GNU_SOURCE  /* But only when HAVE_ASPRINTF */
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -71,7 +72,7 @@ xmlrpc_vasprintf(const char ** const retvalP,
 
 
 
-void GNU_PRINTF_ATTR(2,3)
+void XMLRPC_PRINTF_ATTR(2,3)
 xmlrpc_asprintf(const char ** const retvalP, const char * const fmt, ...) {
 
     va_list varargs;  /* mysterious structure used by variable arg facility */
