@@ -4,6 +4,7 @@
 #include <vector>
 #include <sstream>
 #include <memory>
+#include <cstring>
 #include <time.h>
 
 #include "xmlrpc-c/girerr.hpp"
@@ -307,6 +308,56 @@ public:
 
 
 
+#if XMLRPC_HAVE_TIMEVAL
+
+static struct timeval
+makeTv(time_t       const secs,
+       unsigned int const usecs) {
+
+    struct timeval retval;
+
+    retval.tv_sec  = secs;
+    retval.tv_usec = usecs;
+
+    return retval;
+}
+
+static bool
+tvIsEqual(struct timeval const comparand,
+          struct timeval const comparator) {
+    return
+        comparand.tv_sec  == comparator.tv_sec &&
+        comparand.tv_usec == comparator.tv_usec;
+}
+#endif
+
+
+
+#if XMLRPC_HAVE_TIMESPEC
+
+static struct timespec
+makeTs(time_t       const secs,
+       unsigned int const usecs) {
+
+    struct timespec retval;
+
+    retval.tv_sec  = secs;
+    retval.tv_nsec = usecs * 1000;
+
+    return retval;
+}
+
+static bool
+tsIsEqual(struct timespec const comparand,
+          struct timespec const comparator) {
+    return
+        comparand.tv_sec  == comparator.tv_sec &&
+        comparand.tv_nsec == comparator.tv_nsec;
+}
+#endif
+
+
+
 class datetimeTestSuite : public testSuite {
 public:
     virtual string suiteName() {
@@ -322,6 +373,18 @@ public:
         TEST(val1.type() == value::TYPE_DATETIME);
         value_datetime datetime3(val1);
         TEST(static_cast<time_t>(datetime3) == testTime);
+#if XMLRPC_HAVE_TIMEVAL
+        struct timeval const testTimeTv(makeTv(testTime, 0));
+        value_datetime datetime4(testTimeTv);
+        TEST(static_cast<time_t>(datetime4) == testTime);
+        TEST(tvIsEqual(static_cast<timeval>(datetime4), testTimeTv));
+#endif
+#if XMLRPC_HAVE_TIMESPEC
+        struct timespec const testTimeTs(makeTs(testTime, 0));
+        value_datetime datetime5(testTimeTs);
+        TEST(static_cast<time_t>(datetime5) == testTime);
+        TEST(tsIsEqual(static_cast<timespec>(datetime5), testTimeTs));
+#endif
         try {
             value_datetime datetime4(value_int(4));
             TEST_FAILED("invalid cast int-datetime suceeded");
@@ -418,15 +481,15 @@ public:
     }
     virtual void runtests(unsigned int const) {
         value_i8 int1(7);
-        TEST(static_cast<long long>(int1) == 7);
+        TEST(static_cast<xmlrpc_int64>(int1) == 7);
         value_i8 int2(-7);
-        TEST(static_cast<long long>(int2) == -7);
+        TEST(static_cast<xmlrpc_int64>(int2) == -7);
         value_i8 int5(1ull << 40);
-        TEST(static_cast<long long>(int5) == (1ull << 40));
+        TEST(static_cast<xmlrpc_int64>(int5) == (1ull << 40));
         value val1(int1);
         TEST(val1.type() == value::TYPE_I8);
         value_i8 int3(val1);
-        TEST(static_cast<long long>(int3) == 7);
+        TEST(static_cast<xmlrpc_int64>(int3) == 7);
         try {
             value_i8 int4(value_double(3.7));
             TEST_FAILED("invalid cast double-i8 suceeded");
@@ -554,7 +617,7 @@ public:
         structData.insert(member);
         paramList1.add(value_struct(structData));
         paramList1.add(value_nil());
-        paramList1.add(value_i8((long long)UINT_MAX + 1));
+        paramList1.add(value_i8((xmlrpc_int64)UINT_MAX + 1));
 
         TEST(paramList1.size() == 11);
 
@@ -578,7 +641,7 @@ public:
         TEST(paramList1.getArray(7, 1, 3).size() == 3);
         paramList1.getStruct(8)["the_integer"];
         paramList1.getNil(9);
-        TEST(paramList1.getI8(10) == (long long)UINT_MAX + 1);
+        TEST(paramList1.getI8(10) == (xmlrpc_int64)UINT_MAX + 1);
         paramList1.verifyEnd(11);
 
         paramList paramList2(5);
@@ -608,9 +671,7 @@ main(int argc, char**) {
         paramListTestSuite().run(0);
         registryTestSuite().run(0);
         serverAbyssTestSuite().run(0);
-#ifndef  WIN32
         serverPstreamTestSuite().run(0);
-#endif
         clientTestSuite().run(0);
 
         testXmlRpcCpp();
