@@ -2,6 +2,8 @@
 
 #include "xmlrpc_config.h"
 
+#define _XOPEN_SOURCE 600  /* For strdup(), sigaction */
+
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -186,7 +188,8 @@ sendXmlData(xmlrpc_env * const envP,
     else {
         uint32_t const abyssLen = (uint32_t)len;
 
-        ResponseContentType(abyssSessionP, "text/xml; charset=\"utf-8\"");
+        /* See discussion below of quotes around "utf-8" */
+        ResponseContentType(abyssSessionP, "text/xml; charset=utf-8");
         ResponseContentLength(abyssSessionP, abyssLen);
         
         ResponseWriteStart(abyssSessionP);
@@ -197,6 +200,23 @@ sendXmlData(xmlrpc_env * const envP,
 
 
 
+/* From 0.9.10 (May 2001) through 1.17 (December 2008), the content-type
+   header said charset="utf-8" (i.e. with the value of 'charset' an HTTP quoted
+   string).  Before 0.9.10, the header didn't have charset at all.
+
+   We got a complaint in January 2009 that some client didn't understand that,
+   saying
+
+     apache2: XML-RPC: xmlrpcmsg::parseResponse: invalid charset encoding of
+     received response: "UTF-8"
+
+   And that removing the quotation marks fixes this.
+
+   From what I can tell, the module is wrong to distinguish between the
+   two, but I don't think it hurts anything to use a basic HTTP token instead
+   of an HTTP quoted string here, so starting in 1.18, we do.  */
+
+
 static void
 sendError(TSession *   const abyssSessionP, 
           unsigned int const status,
@@ -1352,7 +1372,7 @@ xmlrpc_server_abyss(xmlrpc_env *                      const envP,
    a thread of a multi-threaded program, use
    xmlrpc_server_abyss_create() instead.  As required by that
    subroutine, your program will contain a call to
-   xmlrpc_server_abyss_init() early in your program, when it is only
+   xmlrpc_server_abyss_global_init() early in your program, when it is only
    one thread.
 -----------------------------------------------------------------------------*/
     XMLRPC_ASSERT_ENV_OK(envP);
